@@ -336,7 +336,8 @@ colors = {
         "FlatButtonDown": "999999",
     },
 }
-"""Color palette. Taken from `2014 Material Design color palettes
+"""
+Color palette. Taken from `2014 Material Design color palettes
 <https://material.io/design/color/the-color-system.html>`_.
 
 To demonstrate the shades of the palette, you can run the following code:
@@ -344,18 +345,17 @@ To demonstrate the shades of the palette, you can run the following code:
 .. code-block:: python
 
     from kivy.lang import Builder
-    from kivy.uix.boxlayout import BoxLayout
-    from kivy.utils import get_color_from_hex
     from kivy.properties import ListProperty, StringProperty
 
     from kivymd.color_definitions import colors
     from kivymd.uix.tab import MDTabsBase
+    from kivymd.uix.boxlayout import MDBoxLayout
 
     demo = '''
-    <Root@BoxLayout>
+    <Root@MDBoxLayout>
         orientation: 'vertical'
 
-        MDToolbar:
+        MDTopAppBar:
             title: app.title
 
         MDTabs:
@@ -365,40 +365,41 @@ To demonstrate the shades of the palette, you can run the following code:
             height: "48dp"
             tab_indicator_anim: False
 
-        ScrollView:
+        RecycleView:
+            id: rv
+            key_viewclass: "viewclass"
+            key_size: "height"
 
-            MDList:
-                id: box
+            RecycleBoxLayout:
+                default_size: None, dp(48)
+                default_size_hint: 1, None
+                size_hint_y: None
+                height: self.minimum_height
+                orientation: "vertical"
 
 
-    <ItemColor>:
+    <ItemColor>
         size_hint_y: None
         height: "42dp"
 
-        canvas:
-            Color:
-                rgba: root.color
-            Rectangle:
-                size: self.size
-                pos: self.pos
-
         MDLabel:
             text: root.text
             halign: "center"
 
 
-    <Tab>:
+    <Tab>
     '''
 
     from kivy.factory import Factory
+
     from kivymd.app import MDApp
 
 
-    class Tab(BoxLayout, MDTabsBase):
+    class Tab(MDBoxLayout, MDTabsBase):
         pass
 
 
-    class ItemColor(BoxLayout):
+    class ItemColor(MDBoxLayout):
         text = StringProperty()
         color = ListProperty()
 
@@ -415,14 +416,19 @@ To demonstrate the shades of the palette, you can run the following code:
                 self.screen.ids.android_tabs.add_widget(tab)
             return self.screen
 
-        def on_tab_switch(self, instance_tabs, instance_tab, instance_tabs_label, tab_text):
-            self.screen.ids.box.clear_widgets()
+        def on_tab_switch(
+            self, instance_tabs, instance_tab, instance_tabs_label, tab_text
+        ):
+            self.screen.ids.rv.data = []
+            if not tab_text:
+                tab_text = 'Red'
             for value_color in colors[tab_text]:
-                self.screen.ids.box.add_widget(
-                    ItemColor(
-                        color=get_color_from_hex(colors[tab_text][value_color]),
-                        text=value_color,
-                    )
+                self.screen.ids.rv.data.append(
+                    {
+                        "viewclass": "ItemColor",
+                        "md_bg_color": colors[tab_text][value_color],
+                        "text": value_color,
+                    }
                 )
 
         def on_start(self):
@@ -915,7 +921,8 @@ text_colors = {
         "A700": "FFFFFF",
     },
 }
-"""Text colors generated from :data:`~light_colors`. "000000" for light and
+"""
+Text colors generated from :data:`~light_colors`. "000000" for light and
 "FFFFFF" for dark.
 
 How to generate text_colors dict
