@@ -1,6 +1,6 @@
 """
-Components/Float Layout
-=======================
+Components/FloatLayout
+======================
 
 :class:`~kivy.uix.floatlayout.FloatLayout` class equivalent. Simplifies working
 with some widget properties. For example:
@@ -8,7 +8,7 @@ with some widget properties. For example:
 FloatLayout
 -----------
 
-.. code-block::
+.. code-block:: kv
 
     FloatLayout:
         canvas:
@@ -22,7 +22,7 @@ FloatLayout
 MDFloatLayout
 -------------
 
-.. code-block::
+.. code-block:: kv
 
     MDFloatLayout:
         radius: [25, 0, 0, 0]
@@ -36,7 +36,11 @@ MDFloatLayout
 from kivy.uix.floatlayout import FloatLayout
 
 from kivymd.uix import MDAdaptiveWidget
+from kivymd.uix.behaviors import DeclarativeBehavior
 
 
-class MDFloatLayout(FloatLayout, MDAdaptiveWidget):
-    pass
+class MDFloatLayout(DeclarativeBehavior, FloatLayout, MDAdaptiveWidget):
+    """
+    Float layout class. For more information, see in the
+    :class:`~kivy.uix.floatlayout.FloatLayout` class documentation.
+    """
